@@ -33,12 +33,14 @@
 #  psymstb               Returns probabilities for symmetric stable DF
 #  qsymstb               Returns quantiles for symmetric stable DF
 #  rsymstb               Returns random variates for symmetric stable DF
+#  .symstb               Returns symmetric alpha-stable pdf/cdf 
 # FUNCTIONS:            STABLE DISTRIBUTION:
-#  stableMode            Computes stable mode
 #  dstable               Returns density for stable DF
 #  pstable               Returns probabilities for stable DF
 #  qstable               Returns quantiles for stable DF
 #  rstable               Returns random variates for stable DF
+#  stableMode            Computes the mode of the stable DF
+#  .integrateStable      Integrates internal functions for *stable
 # FUNCTION:             STABLE SLIDERS:
 #  symstbSlider          Displays symmetric stable distribution function
 #  stableSlider          Displays stable distribution function
@@ -50,38 +52,25 @@
 #  psymstb               Returns probabilities for symmetric stable DF
 #  qsymstb               Returns quantiles for symmetric stable DF
 #  rsymstb               Returns random variates for symmetric stable DF
+#  .symstb               Returns symmetric alpha-stable pdf/cdf  
 
 
-dsymstb = 
-function (x, alpha)
-{   # # A function implemented by Diethelm Wuertz
-  
+dsymstb =
+function(x, alpha = 1.8)
+{   # A function implemented by Diethelm Wuertz
+
     # Description:
-    #   Return symmetric alpha-stable pdf
-    
-    # Note: 
-    #   symstb - returns symmetric alpha-stable pdf/cdf. The function  
-    #   implements J.H. McCulloch's Fortran program for symmetric 
-    #   distributions. Mc Cullochs approach has a density precision of 
-    #   0.000066 and a distribution precision of 0.000022 for alpha in  
-    #   the range [0.84, 2.00]. We have added only first order tail 
-    #   approximation to calculate the tail density and probability.
-    #   This has still to be improved!
-
-    # Changes:
-    #
+    #   Returns density for symmetric stable DF
     
     # FUNCTION:
     
     # Density:
-    ans = .Fortran("symstb",
-        as.double(x),
-        as.double(1:length(x)),
-        as.double(1:length(x)),
-        as.integer(length(x)),
-        as.double(alpha),
-        PACKAGE = "fBasics")[[3]]
-        
+    ans = as.vector(.symstb(x = x, alpha = alpha)[, "d"])
+    
+    # Attributes:
+    attr(ans, "control") = 
+        cbind.data.frame(dist = "symstb", alpha = alpha, row.names = "")
+      
     # Return Value:
     ans
 }
@@ -90,38 +79,22 @@ function (x, alpha)
 # ------------------------------------------------------------------------------
 
 
-psymstb = 
-function (q, alpha)
+psymstb =
+function(q, alpha = 1.8)
 {   # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Return symmetric alpha-stable cdf
-
-    # Notes: 
-    #   symstb:
-    #   Return symmetric alpha-stable pdf/cdf. The function
-    #   implements J.H. McCulloch's Fortran program for symmetric
-    #   distributions.
-    #   Mc Cullochs approach has a density precision of 0.000066
-    #   and a distribution precision of 0.000022 for alpha in the 
-    #   range [0.84, 2.00]. We have added only first order tail 
-    #   approximation to calculate the tail density and probability.
-    #   This has still to be improved!
-    
-    # Changes:
-    #
+    #   Returns probabilities for symmetric stable DF
     
     # FUNCTION:
     
-    # Return Value:
-    ans = .Fortran("symstb",
-        as.double(q),
-        as.double(1:length(q)),
-        as.double(1:length(q)),
-        as.integer(length(q)),
-        as.double(alpha),
-        PACKAGE = "fBasics")[[2]]
-        
+    # Probability:
+    ans = as.vector(.symstb(x = q, alpha = alpha)[, "p"])
+    
+    # Attributes:
+    attr(ans, "control") = 
+        cbind.data.frame(dist = "symstb", alpha = alpha, row.names = "")
+    
     # Return Value:
     ans
 }
@@ -134,8 +107,8 @@ qsymstb =
 function(p, alpha)
 {   # A function implemented by Diethelm Wuertz
 
-    # Changes:
-    #
+    # Description:
+    #   Returns quantiles for symmetric stable DF
     
     # FUNCTION:
     
@@ -181,8 +154,13 @@ function(p, alpha)
         } 
     }
     
+    # Attributes:
+    ans = result
+    attr(ans, "control") = 
+        cbind.data.frame(dist = "symstb", alpha = alpha, row.names = "")
+    
     # Return Value:
-    result
+    ans
 }
 
 
@@ -194,13 +172,13 @@ function(n, alpha)
 {   # A function implemented by Diethelm Wuertz
     
     # Description:
+    #   Returns random variates for symmetric stable DF
+    
+    # Details:
     #   Return random deviates from the stable family 
     #   of probability distributions. The results of 
     #   Chambers, Mallows, and Stuck is used.
 
-    # Changes:
-    #
-    
     # FUNCTION:
     
     # Calculate uniform and exponential distributed random numbers:
@@ -216,13 +194,165 @@ function(n, alpha)
     } 
     
     # Add Attribute:
-    attr(result, "control") = c(dist = "symstb", alpha = as.character(alpha))
+    ans = result
+    attr(ans, "control") = 
+        cbind.data.frame(dist = "symstb", alpha = alpha, row.names = "")
     
     # Return Value:
-    result
+    ans
 }
 
 
+# ------------------------------------------------------------------------------
+
+
+.symstb =
+function(x, alpha)
+{   # A function implemented by Diethelm Wuertz
+
+    # Description:
+    #   Returns symmetric alpha-stable pdf/cdf
+    
+    # Note: 
+    #   symstb - returns symmetric alpha-stable pdf/cdf. The function  
+    #   implements J.H. McCulloch's Fortran program for symmetric 
+    #   distributions. Mc Cullochs approach has a density precision of 
+    #   0.000066 and a distribution precision of 0.000022 for alpha in  
+    #   the range [0.84, 2.00]. We have added only first order tail 
+    #   approximation to calculate the tail density and probability.
+    #   This has still to be improved!
+    
+    # FUNCTION:
+    
+    # Settings:
+    X = prob = dens = x
+    N = length(x)
+    ei = 1:3
+    u = rep(1, 3)
+    q = rep(0, times = 6)
+    p = matrix(rep(0, 120), ncol = 20)
+    pd = matrix(rep(0, 100), ncol = 20)
+    r = znot = zn4 = zn5 = rep(0, 19)
+    zji = matrix(rep(0, 114), ncol = 6)
+    combo = c(1, 5, 10, 10, 5, 1)
+    s = matrix(c(                   
+         1.8514190959e2, -4.6769332663e2,  4.8424720302e2, -1.7639153404e2,               
+        -3.0236552164e2,  7.6351931975e2, -7.8560342101e2,  2.8426313374e2,               
+         4.4078923600e2, -1.1181138121e3,  1.1548311335e3, -4.1969666223e2,               
+        -5.2448142165e2,  1.3224487717e3, -1.3555648053e3,  4.8834079950e2,               
+         5.3530435018e2, -1.3374570340e3,  1.3660140118e3, -4.9286099583e2,               
+        -4.8988957866e2,  1.2091418165e3, -1.2285872257e3,  4.4063174114e2,               
+         3.2905528742e2, -7.3211767697e2,  6.8183641829e2, -2.2824291084e2,               
+        -2.1495402244e2,  3.9694906604e2, -3.3695710692e2,  1.0905855709e2,               
+         2.1112581866e2, -2.7921107017e2,  1.1717966020e2,  3.4394664342e0,               
+        -2.6486798043e2,  1.1999093707e2,  2.1044841328e2, -1.5110881541e2,               
+         9.4105784123e2, -1.7221988478e3,  1.4087544698e3, -4.2472511892e2,               
+        -2.1990475933e3,  4.2637720422e3, -3.4723981786e3,  1.0174373627e3,               
+         3.1047490290e3, -5.4204210990e3,  4.2221052925e3, -1.2345971177e3,               
+        -5.1408260668e3,  1.1090264364e4, -1.0270337246e4,  3.4243449595e3,               
+         1.1215157876e4, -2.4243529825e4,  2.1536057267e4, -6.8490996103e3,               
+        -1.8120631586e4,  3.1430132257e4, -2.4164285641e4,  6.9126862826e3,               
+         1.7388413126e4, -2.2108397686e4,  1.3397999271e4, -3.1246611987e3,               
+        -7.2435775303e3,  4.3545399418e3,  2.3616155949e2, -7.6571653073e2,               
+        -8.7376725439e3,  1.5510852129e4, -1.3789764138e4,  4.6387417712e3),  
+    byrow = FALSE, ncol = 19)             
+                      
+    # Setup:
+    ca = gamma(alpha)*sin(pi*alpha/2)/pi
+    sqpi = sqrt(pi)
+    a2 = sqrt(2)-1
+    cpxp0 = 1 / pi
+    gpxp0 = 1 / (4*a2*sqpi)
+    cpxpp0 = 2 * cpxp0
+    gpxpp0 = 1.5 * gpxp0
+    cppp = cpxpp0*3 - 2/pi
+    gppp = gpxpp0*2.5 - 1/(32*sqpi*a2^3)
+    znot = (1:19)*0.05
+    zn4 = (1-znot)^4
+    zn5 = (1-znot)*zn4   
+    for (j in 1:19) 
+        for (i in 0:5) 
+            zji[j, i+1] = combo[i+1] * (-znot[j])^(5-i)        
+    a = 2^(1/alpha)-1
+    sp0 = gamma(1/alpha)/(pi*alpha)
+    sppp0 = -gamma(3/alpha)/(pi*alpha)
+    xp0 = 1/(alpha*a)
+    xpp0 = xp0*(1+alpha)/alpha
+    xppp0 = xpp0*(1+2*alpha)/alpha
+    spzp1 = (a^alpha)*gamma(alpha)*sin((pi*alpha)/2)/pi
+    rp0 = -sp0*xp0 + (2-alpha)*cpxp0 + (alpha-1)*gpxp0
+    rpp0 = -sp0*xpp0 + (2-alpha)*cpxpp0 + (alpha-1)*gpxpp0
+    rppp0 = -sp0*xppp0 - sppp0*xp0^3 + (2-alpha)*cppp + (alpha-1)*gppp
+    rp1 = -spzp1 + (2-alpha)/pi 
+    alf2i = (2-alpha)^(1:4)-1
+    r = (2-alpha)*(alf2i[1]*s[1,]+alf2i[2]*s[2,]+alf2i[3]*s[3,]+alf2i[4]*s[4,])   
+    
+    # Setup Q:
+    q[1] = 0
+    q[2] = rp0
+    q[3] = rpp0/2
+    q[4] = rppp0/6
+    bb = -sum(u*q[2:4]) - sum(r*zn5)
+    cc = rp1 - sum(ei*q[2:4]) - 5*sum(r*zn4)
+    q[5] = 5*bb - cc
+    q[6] = bb - q[4+1]     
+    
+    # Setup P and PD:
+    p[, 1] = q
+    for (i in 0:5) {
+        for (j in 1:19) {
+            p[i+1, j+1] = q[i+1] + cumsum(r*zji[, i+1])[j]
+        }     
+    }  
+    for (i in 1:5) pd[i, ] = i*p[i+1, ]    
+    
+    # Loop over all datapoints:
+    for (I in 1:N) {
+        x = X[I]
+        xa1 = 1 + a*abs(x)
+        xa1a = xa1^(-alpha)
+        z = 1 - xa1a
+        zp = (alpha*a)*xa1a/xa1
+        x1 = ((1-z)^(-1)-1)
+        x2 = ((1-z)^(-0.5)-1) / a2
+        x1p = 1 / ((1+x1)^(-2))
+        x2p = 1 / (2*a2*(1+a2*x2)^(-3))
+        j = floor(20 * z)
+        j = min(19, j) 
+        # RZ:
+        A = as.vector(p[(0:5)+1, j+1])
+        K = 5
+        poly = A[K+1]
+        for (j in K:1) poly = poly * z + A[j]
+        rz = poly
+        # RPZ:
+        A = as.vector(pd[(0:4)+1, j+1])
+        K = 4
+        poly = A[K+1]
+        for (j in K:1) poly = poly * z + A[j]
+        rpz = poly
+        # Cumulated probability function:
+        cfun = 0.5 - atan(x1) / pi
+        gfun = 1 - pnorm(x2 / sqrt(2))
+        probfun = (2-alpha)*cfun + (alpha-1)*gfun + rz
+        if (x < 0) probfun = 1 - probfun 
+        prob[I] = 1 - probfun
+        if (prob[I] < 2.2e-4) prob[I] = ca * abs(x)^(-alpha)
+        
+        # Probability density function:
+        cden = 1 / (pi*(1+x1*x1))
+        gden = exp(-x2*x2/4)/(2*sqpi)
+        probden = ((2-alpha)*cden*x1p + (alpha-1)*gden*x2p - rpz) * zp
+        dens[I] = probden
+        if (dens[I] < 6.6e-4) dens[I] = alpha*ca*abs(x)^(-alpha-1)
+    }
+      
+    # Return Value:
+    cbind(x = X, p = prob, d = dens)
+}  
+ 
+
+
 ################################################################################
 #  dstable               Returns density for stable DF
 #  pstable               Returns probabilities for stable DF
@@ -237,8 +367,9 @@ function(x, alpha, beta, gamma = 1, delta = 0, pm = c(0, 1, 2))
 {   # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Return alpha-stable density function (pdf) in form
-    #   of parmeterization 1. 
+    #   Returns density for stable DF
+    
+    # Details:
     #   The function uses the approach of J.P. Nolan for general 
     #   stable distributions. Nolan derived expressions in form 
     #   of integrals based on the charcteristic function for
@@ -258,9 +389,6 @@ function(x, alpha, beta, gamma = 1, delta = 0, pm = c(0, 1, 2))
     #       integrate()$value and integrate()$integral.
     #   optimize() works in both R and SPlus.
 
-    # Changes:
-    #
-    
     # FUNCTION:
     
     # Settings:
@@ -404,6 +532,11 @@ function(x, alpha, beta, gamma = 1, delta = 0, pm = c(0, 1, 2))
     # Result:
     ans = result/gamma
     
+    # Attributes:
+    attr(ans, "control") = 
+        cbind.data.frame(dist = "stable", alpha = alpha, beta = beta,
+            gamma = gamma, delta = delta, pm = pm, row.names = "")
+    
     # Return Value:
     ans
 }
@@ -416,8 +549,8 @@ pstable =
 function(q, alpha, beta, gamma = 1, delta = 0, pm = c(0, 1, 2))
 {   # A function implemented by Diethelm Wuertz
 
-    # Changes:
-    #
+    # Description:
+    #   Returns probability for stable DF
     
     # FUNCTION:
     
@@ -554,8 +687,14 @@ function(q, alpha, beta, gamma = 1, delta = 0, pm = c(0, 1, 2))
         }
     }
 
+    # Attributes:
+    ans = result
+    attr(ans, "control") = 
+        cbind.data.frame(dist = "stable", alpha = alpha, beta = beta,
+            gamma = gamma, delta = delta, pm = pm, row.names = "")
+            
     # Return Value:
-    result
+    ans
 }
 
 
@@ -566,8 +705,8 @@ qstable =
 function(p, alpha, beta, gamma = 1, delta = 0, pm = c(0, 1, 2))
 {   # A function implemented by Diethelm Wuertz
 
-    # Changes:
-    #
+    # Description:
+    #   Returns quantiles for stable DF
     
     # FUNCTION:
     
@@ -661,6 +800,11 @@ function(p, alpha, beta, gamma = 1, delta = 0, pm = c(0, 1, 2))
     # Result:
     ans = result * gamma + delta
     
+    # Attributes:
+    attr(ans, "control") = 
+        cbind.data.frame(dist = "stable", alpha = alpha, beta = beta,
+            gamma = gamma, delta = delta, pm = pm, row.names = "")
+            
     # Return Value:
     ans
 }
@@ -674,12 +818,8 @@ function(n, alpha, beta, gamma = 1, delta = 0, pm = c(0, 1, 2))
 {   # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Return random deviates from the stable family 
-    #   of probability distributions.
+    #   Returns random variates for stable DF
 
-    # Changes:
-    #
-    
     # FUNCTION:
     
     # Parameter Check:
@@ -723,10 +863,10 @@ function(n, alpha, beta, gamma = 1, delta = 0, pm = c(0, 1, 2))
     # Result:
     ans = result * gamma + delta
     
-    # Add Attribute:
-    attr(ans, "control") = c(dist = "stable", alpha = as.character(alpha),
-        beta = as.character(beta), gamma = as.character(gamma),
-        delta = as.character(delta), pm = as.character(pm))
+    # Attributes:
+    attr(ans, "control") = 
+        cbind.data.frame(dist = "stable", alpha = alpha, beta = beta,
+            gamma = gamma, delta = delta, pm = pm, row.names = "")
     
     # Return Value:
     ans
@@ -741,7 +881,7 @@ function(alpha, beta)
 {   # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Compute the mode of the stable distribution function
+    #   Computes the mode of the stable DF
     
     # Notes:
     #   # Test for values close to beta = 1
@@ -768,9 +908,6 @@ function(alpha, beta)
     #   1.8   -5.098617e-02 -5.145758e-02 -5.145639e-02 -5.145639e-02
     #   2.0   -7.487432e-05 -7.487432e-05 -7.487432e-05 -7.487432e-05
 
-    # Changes:
-    #
-    
     # FUNCTION:
     
     # Stable Mode:
@@ -786,6 +923,11 @@ function(alpha, beta)
         }
     }
     
+    # Attributes:
+    attr(ans, "control") = 
+        cbind.data.frame(dist = "stable", alpha = alpha, beta = beta,
+        row.names = "")
+            
     # Return Value:
     ans
 }
@@ -798,8 +940,8 @@ function(alpha, beta)
 function (f, lower, upper, subdivisions, rel.tol, abs.tol, ...) 
 {   # A function implemented by Diethelm Wuertz
 
-    # Changes:
-    #
+    # Description:
+    #   Internal Function
     
     # FUNCTION:
     
@@ -818,13 +960,13 @@ function (f, lower, upper, subdivisions, rel.tol, abs.tol, ...)
         # SPlus:
         ans = integrate(f, lower, upper, subdivisions, rel.tol, abs.tol, ...) 
     }
+    
     # Return Value:
     ans
 
 }
 
 
-
 ################################################################################
 #  symstbSlider          Displays symmetric stable distribution function
 #  stableSlider          Displays stable distribution function
@@ -836,10 +978,7 @@ function()
 
     # Description
     #   Displays the symmetric stable distribution
-    
-    # Changes:
-    #
-    
+
     # FUNCTION:
     
     # Internal Function:
@@ -899,9 +1038,6 @@ function()
     # Description:
     #   Displays the stable distribution
 
-    # Changes:
-    #
-    
     # FUNCTION:
     
     # Internal Function:
